@@ -3,15 +3,13 @@ use cloudflare::framework::apiclient::ApiClient;
 use cloudflare::framework::response::{ApiFailure, ApiSuccess};
 use cloudflare::framework::HttpApiClient;
 
-use crate::settings::toml::Target;
-
 pub fn delete(
     client: HttpApiClient,
-    target: &Target,
+    account_id: &str,
     id: &str,
 ) -> Result<ApiSuccess<()>, ApiFailure> {
     client.request(&RemoveNamespace {
-        account_identifier: &target.account_id,
+        account_identifier: account_id,
         namespace_identifier: id,
     })
 }
