@@ -5,6 +5,7 @@ mod environment;
 mod kv_namespace;
 mod manifest;
 pub mod migrations;
+mod r2_bucket;
 mod route;
 mod site;
 pub(crate) mod target;
@@ -15,6 +16,7 @@ pub use builder::{ModuleRule, UploadFormat};
 pub use durable_objects::{DurableObjects, DurableObjectsClass};
 pub use kv_namespace::{ConfigKvNamespace, KvNamespace};
 pub use manifest::Manifest;
+pub use r2_bucket::{ConfigR2Bucket, R2Bucket};
 pub use route::{Route, RouteConfig};
 pub use site::Site;
 pub use target::Target;
